==> apigateway-0.33.0-sources.jar: software/amazon/awscdk/services/apigateway/IResource.java <==
package software.amazon.awscdk.services.apigateway;

@javax.annotation.Generated(value = "jsii-pacmak/0.11.0 (build 3d6415e)", date = "2019-05-30T15:06:14.435Z")
public interface IResource extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.IResource {
    /**
     * The full path of this resuorce.
     */
    java.lang.String getPath();
    /**
     * The ID of the resource.
     */
    java.lang.String getResourceId();
    /**
     * The rest API that this resource is part of.
     * 
     * The reason we need the RestApi object itself and not just the ID is because the model
     * is being tracked by the top-level RestApi object for the purpose of calculating it's
     * hash to determine the ID of the deployment. This allows us to automatically update
     * the deployment when the model of the REST API changes.
     */
    software.amazon.awscdk.services.apigateway.RestApi getRestApi();
    /**
     * An integration to use as a default for all methods created within this API unless an integration is specified.
     */
    software.amazon.awscdk.services.apigateway.Integration getDefaultIntegration();
    /**
     * Method options to use as a default for all methods created within this API unless custom options are specified.
     */
    software.amazon.awscdk.services.apigateway.MethodOptions getDefaultMethodOptions();
    /**
     * The parent of this resource or undefined for the root resource.
     */
    software.amazon.awscdk.services.apigateway.IResource getParentResource();
    /**
     * Defines a new method for this resource.
     * 
     * @return The newly created `Method` object.
     * @param httpMethod The HTTP method.
     * @param target The target backend integration for this method.
     * @param options Method options, such as authentication.
     */
    software.amazon.awscdk.services.apigateway.Method addMethod(final java.lang.String httpMethod, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.Integration target, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.MethodOptions options);
    /**
     * Defines a new method for this resource.
     * 
     * @return The newly created `Method` object.
     * @param httpMethod The HTTP method.
     * @param target The target backend integration for this method.
     */
    software.amazon.awscdk.services.apigateway.Method addMethod(final java.lang.String httpMethod, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.Integration target);
    /**
     * Defines a new method for this resource.
     * 
     * @return The newly created `Method` object.
     * @param httpMethod The HTTP method.
     */
    software.amazon.awscdk.services.apigateway.Method addMethod(final java.lang.String httpMethod);
    /**
     * Adds a greedy proxy resource ("{proxy+}") and an ANY method to this route.
     * 
     * @param options Default integration and method options.
     */
    software.amazon.awscdk.services.apigateway.ProxyResource addProxy(@javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.ResourceOptions options);
    /**
     * Adds a greedy proxy resource ("{proxy+}") and an ANY method to this route.
     */
    software.amazon.awscdk.services.apigateway.ProxyResource addProxy();
    /**
     * Defines a new child resource where this resource is the parent.
     * 
     * @return A Resource object
     * @param pathPart The path part for the child resource.
     * @param options Resource options.
     */
    software.amazon.awscdk.services.apigateway.Resource addResource(final java.lang.String pathPart, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.ResourceOptions options);
    /**
     * Defines a new child resource where this resource is the parent.
     * 
     * @return A Resource object
     * @param pathPart The path part for the child resource.
     */
    software.amazon.awscdk.services.apigateway.Resource addResource(final java.lang.String pathPart);
    /**
     * Retrieves a child resource by path part.
     * 
     * @return the child resource or undefined if not found
     * @param pathPart The path part of the child resource.
     */
    software.amazon.awscdk.services.apigateway.IResource getResource(final java.lang.String pathPart);
    /**
     * Gets or create all resources leading up to the specified path.
     * 
     * - Path may only start with "/" if this method is called on the root resource.
     * - All resources are created using default options.
     * 
     * @return a new or existing resource.
     * @param path The relative path.
     */
    software.amazon.awscdk.services.apigateway.Resource resourceForPath(final java.lang.String path);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.apigateway.IResource {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The full path of this resuorce.
         */
        @Override
        public java.lang.String getPath() {
            return this.jsiiGet("path", java.lang.String.class);
        }

        /**
         * The ID of the resource.
         */
        @Override
        public java.lang.String getResourceId() {
            return this.jsiiGet("resourceId", java.lang.String.class);
        }

        /**
         * The rest API that this resource is part of.
         * 
         * The reason we need the RestApi object itself and not just the ID is because the model
         * is being tracked by the top-level RestApi object for the purpose of calculating it's
         * hash to determine the ID of the deployment. This allows us to automatically update
         * the deployment when the model of the REST API changes.
         */
        @Override
        public software.amazon.awscdk.services.apigateway.RestApi getRestApi() {
            return this.jsiiGet("restApi", software.amazon.awscdk.services.apigateway.RestApi.class);
        }

        /**
         * An integration to use as a default for all methods created within this API unless an integration is specified.
         */
        @Override
        @javax.annotation.Nullable
        public software.amazon.awscdk.services.apigateway.Integration getDefaultIntegration() {
            return this.jsiiGet("defaultIntegration", software.amazon.awscdk.services.apigateway.Integration.class);
        }

        /**
         * Method options to use as a default for all methods created within this API unless custom options are specified.
         */
        @Override
        @javax.annotation.Nullable
        public software.amazon.awscdk.services.apigateway.MethodOptions getDefaultMethodOptions() {
            return this.jsiiGet("defaultMethodOptions", software.amazon.awscdk.services.apigateway.MethodOptions.class);
        }

        /**
         * The parent of this resource or undefined for the root resource.
         */
        @Override
        @javax.annotation.Nullable
        public software.amazon.awscdk.services.apigateway.IResource getParentResource() {
            return this.jsiiGet("parentResource", software.amazon.awscdk.services.apigateway.IResource.class);
        }

        /**
         * The construct node in the scope tree.
         */
        @Override
        public software.amazon.awscdk.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.ConstructNode.class);
        }

        /**
         * Defines a new method for this resource.
         * 
         * @return The newly created `Method` object.
         * @param httpMethod The HTTP method.
         * @param target The target backend integration for this method.
         * @param options Method options, such as authentication.
         */
        @Override
        public software.amazon.awscdk.services.apigateway.Method addMethod(final java.lang.String httpMethod, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.Integration target, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.MethodOptions options) {
            return this.jsiiCall("addMethod", software.amazon.awscdk.services.apigateway.Method.class, new Object[] { java.util.Objects.requireNonNull(httpMethod, "httpMethod is required"), target, options });
        }

        /**
         * Defines a new method for this resource.
         * 
         * @return The newly created `Method` object.
         * @param httpMethod The HTTP method.
         * @param target The target backend integration for this method.
         */
        @Override
        public software.amazon.awscdk.services.apigateway.Method addMethod(final java.lang.String httpMethod, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.Integration target) {
            return this.jsiiCall("addMethod", software.amazon.awscdk.services.apigateway.Method.class, new Object[] { java.util.Objects.requireNonNull(httpMethod, "httpMethod is required"), target });
        }

        /**
         * Defines a new method for this resource.
         * 
         * @return The newly created `Method` object.
         * @param httpMethod The HTTP method.
         */
        @Override
        public software.amazon.awscdk.services.apigateway.Method addMethod(final java.lang.String httpMethod) {
            return this.jsiiCall("addMethod", software.amazon.awscdk.services.apigateway.Method.class, new Object[] { java.util.Objects.requireNonNull(httpMethod, "httpMethod is required") });
        }

        /**
         * Adds a greedy proxy resource ("{proxy+}") and an ANY method to this route.
         * 
         * @param options Default integration and method options.
         */
        @Override
        public software.amazon.awscdk.services.apigateway.ProxyResource addProxy(@javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.ResourceOptions options) {
            return this.jsiiCall("addProxy", software.amazon.awscdk.services.apigateway.ProxyResource.class, new Object[] { options });
        }

        /**
         * Adds a greedy proxy resource ("{proxy+}") and an ANY method to this route.
         */
        @Override
        public software.amazon.awscdk.services.apigateway.ProxyResource addProxy() {
            return this.jsiiCall("addProxy", software.amazon.awscdk.services.apigateway.ProxyResource.class);
        }

        /**
         * Defines a new child resource where this resource is the parent.
         * 
         * @return A Resource object
         * @param pathPart The path part for the child resource.
         * @param options Resource options.
         */
        @Override
        public software.amazon.awscdk.services.apigateway.Resource addResource(final java.lang.String pathPart, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.ResourceOptions options) {
            return this.jsiiCall("addResource", software.amazon.awscdk.services.apigateway.Resource.class, new Object[] { java.util.Objects.requireNonNull(pathPart, "pathPart is required"), options });
        }

        /**
         * Defines a new child resource where this resource is the parent.
         * 
         * @return A Resource object
         * @param pathPart The path part for the child resource.
         */
        @Override
        public software.amazon.awscdk.services.apigateway.Resource addResource(final java.lang.String pathPart) {
            return this.jsiiCall("addResource", software.amazon.awscdk.services.apigateway.Resource.class, new Object[] { java.util.Objects.requireNonNull(pathPart, "pathPart is required") });
        }

        /**
         * Retrieves a child resource by path part.
         * 
         * @return the child resource or undefined if not found
         * @param pathPart The path part of the child resource.
         */
        @Override
        @javax.annotation.Nullable
        public software.amazon.awscdk.services.apigateway.IResource getResource(final java.lang.String pathPart) {
            return this.jsiiCall("getResource", software.amazon.awscdk.services.apigateway.IResource.class, new Object[] { java.util.Objects.requireNonNull(pathPart, "pathPart is required") });
        }

        /**
         * Gets or create all resources leading up to the specified path.
         * 
         * - Path may only start with "/" if this method is called on the root resource.
         * - All resources are created using default options.
         * 
         * @return a new or existing resource.
         * @param path The relative path.
         */
        @Override
        public software.amazon.awscdk.services.apigateway.Resource resourceForPath(final java.lang.String path) {
            return this.jsiiCall("resourceForPath", software.amazon.awscdk.services.apigateway.Resource.class, new Object[] { java.util.Objects.requireNonNull(path, "path is required") });
        }
    }
}

==> apigateway-0.34.0-sources.jar: software/amazon/awscdk/services/apigateway/IResource.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.11.2 (build 27d16c2)", date = "2019-06-10T11:12:46.519Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface IResource extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.IResource {
    /**
     * The full path of this resuorce.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getPath();
    /**
     * The ID of the resource.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getResourceId();
    /**
     * The rest API that this resource is part of.
     * 
     * The reason we need the RestApi object itself and not just the ID is because the model
     * is being tracked by the top-level RestApi object for the purpose of calculating it's
     * hash to determine the ID of the deployment. This allows us to automatically update
     * the deployment when the model of the REST API changes.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.services.apigateway.RestApi getRestApi();
    /**
     * An integration to use as a default for all methods created within this API unless an integration is specified.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.services.apigateway.Integration getDefaultIntegration();
    /**
     * Method options to use as a default for all methods created within this API unless custom options are specified.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.services.apigateway.MethodOptions getDefaultMethodOptions();
    /**
     * The parent of this resource or undefined for the root resource.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.services.apigateway.IResource getParentResource();
    /**
     * Defines a new method for this resource.
     * 
     * EXPERIMENTAL
     * 
     * @return The newly created `Method` object.
     * @param httpMethod The HTTP method.
     * @param target The target backend integration for this method.
     * @param options Method options, such as authentication.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.services.apigateway.Method addMethod(final java.lang.String httpMethod, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.Integration target, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.MethodOptions options);
    /**
     * Defines a new method for this resource.
     * 
     * EXPERIMENTAL
     * 
     * @return The newly created `Method` object.
     * @param httpMethod The HTTP method.
     * @param target The target backend integration for this method.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.services.apigateway.Method addMethod(final java.lang.String httpMethod, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.Integration target);
    /**
     * Defines a new method for this resource.
     * 
     * EXPERIMENTAL
     * 
     * @return The newly created `Method` object.
     * @param httpMethod The HTTP method.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.services.apigateway.Method addMethod(final java.lang.String httpMethod);
    /**
     * Adds a greedy proxy resource ("{proxy+}") and an ANY method to this route.
     * 
     * EXPERIMENTAL
     * 
     * @param options Default integration and method options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.services.apigateway.ProxyResource addProxy(@javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.ResourceOptions options);
    /**
     * Adds a greedy proxy resource ("{proxy+}") and an ANY method to this route.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.services.apigateway.ProxyResource addProxy();
    /**
     * Defines a new child resource where this resource is the parent.
     * 
     * EXPERIMENTAL
     * 
     * @return A Resource object
     * @param pathPart The path part for the child resource.
     * @param options Resource options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.services.apigateway.Resource addResource(final java.lang.String pathPart, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.ResourceOptions options);
    /**
     * Defines a new child resource where this resource is the parent.
     * 
     * EXPERIMENTAL
     * 
     * @return A Resource object
     * @param pathPart The path part for the child resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.services.apigateway.Resource addResource(final java.lang.String pathPart);
    /**
     * Retrieves a child resource by path part.
     * 
     * EXPERIMENTAL
     * 
     * @return the child resource or undefined if not found
     * @param pathPart The path part of the child resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.services.apigateway.IResource getResource(final java.lang.String pathPart);
    /**
     * Gets or create all resources leading up to the specified path.
     * 
     * - Path may only start with "/" if this method is called on the root resource.
     * - All resources are created using default options.
     * 
     * EXPERIMENTAL
     * 
     * @return a new or existing resource.
     * @param path The relative path.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.services.apigateway.Resource resourceForPath(final java.lang.String path);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.apigateway.IResource {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The full path of this resuorce.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public java.lang.String getPath() {
            return this.jsiiGet("path", java.lang.String.class);
        }

        /**
         * The ID of the resource.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public java.lang.String getResourceId() {
            return this.jsiiGet("resourceId", java.lang.String.class);
        }

        /**
         * The rest API that this resource is part of.
         * 
         * The reason we need the RestApi object itself and not just the ID is because the model
         * is being tracked by the top-level RestApi object for the purpose of calculating it's
         * hash to determine the ID of the deployment. This allows us to automatically update
         * the deployment when the model of the REST API changes.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public software.amazon.awscdk.services.apigateway.RestApi getRestApi() {
            return this.jsiiGet("restApi", software.amazon.awscdk.services.apigateway.RestApi.class);
        }

        /**
         * An integration to use as a default for all methods created within this API unless an integration is specified.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @javax.annotation.Nullable
        public software.amazon.awscdk.services.apigateway.Integration getDefaultIntegration() {
            return this.jsiiGet("defaultIntegration", software.amazon.awscdk.services.apigateway.Integration.class);
        }

        /**
         * Method options to use as a default for all methods created within this API unless custom options are specified.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @javax.annotation.Nullable
        public software.amazon.awscdk.services.apigateway.MethodOptions getDefaultMethodOptions() {
            return this.jsiiGet("defaultMethodOptions", software.amazon.awscdk.services.apigateway.MethodOptions.class);
        }

        /**
         * The parent of this resource or undefined for the root resource.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @javax.annotation.Nullable
        public software.amazon.awscdk.services.apigateway.IResource getParentResource() {
            return this.jsiiGet("parentResource", software.amazon.awscdk.services.apigateway.IResource.class);
        }

        /**
         * The construct node in the scope tree.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public software.amazon.awscdk.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.ConstructNode.class);
        }

        /**
         * Defines a new method for this resource.
         * 
         * EXPERIMENTAL
         * 
         * @return The newly created `Method` object.
         * @param httpMethod The HTTP method.
         * @param target The target backend integration for this method.
         * @param options Method options, such as authentication.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.apigateway.Method addMethod(final java.lang.String httpMethod, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.Integration target, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.MethodOptions options) {
            return this.jsiiCall("addMethod", software.amazon.awscdk.services.apigateway.Method.class, new Object[] { java.util.Objects.requireNonNull(httpMethod, "httpMethod is required"), target, options });
        }

        /**
         * Defines a new method for this resource.
         * 
         * EXPERIMENTAL
         * 
         * @return The newly created `Method` object.
         * @param httpMethod The HTTP method.
         * @param target The target backend integration for this method.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.apigateway.Method addMethod(final java.lang.String httpMethod, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.Integration target) {
            return this.jsiiCall("addMethod", software.amazon.awscdk.services.apigateway.Method.class, new Object[] { java.util.Objects.requireNonNull(httpMethod, "httpMethod is required"), target });
        }

        /**
         * Defines a new method for this resource.
         * 
         * EXPERIMENTAL
         * 
         * @return The newly created `Method` object.
         * @param httpMethod The HTTP method.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.apigateway.Method addMethod(final java.lang.String httpMethod) {
            return this.jsiiCall("addMethod", software.amazon.awscdk.services.apigateway.Method.class, new Object[] { java.util.Objects.requireNonNull(httpMethod, "httpMethod is required") });
        }

        /**
         * Adds a greedy proxy resource ("{proxy+}") and an ANY method to this route.
         * 
         * EXPERIMENTAL
         * 
         * @param options Default integration and method options.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.apigateway.ProxyResource addProxy(@javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.ResourceOptions options) {
            return this.jsiiCall("addProxy", software.amazon.awscdk.services.apigateway.ProxyResource.class, new Object[] { options });
        }

        /**
         * Adds a greedy proxy resource ("{proxy+}") and an ANY method to this route.
         * 
         * EXPERIMENTAL
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.apigateway.ProxyResource addProxy() {
            return this.jsiiCall("addProxy", software.amazon.awscdk.services.apigateway.ProxyResource.class);
        }

        /**
         * Defines a new child resource where this resource is the parent.
         * 
         * EXPERIMENTAL
         * 
         * @return A Resource object
         * @param pathPart The path part for the child resource.
         * @param options Resource options.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.apigateway.Resource addResource(final java.lang.String pathPart, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.ResourceOptions options) {
            return this.jsiiCall("addResource", software.amazon.awscdk.services.apigateway.Resource.class, new Object[] { java.util.Objects.requireNonNull(pathPart, "pathPart is required"), options });
        }

        /**
         * Defines a new child resource where this resource is the parent.
         * 
         * EXPERIMENTAL
         * 
         * @return A Resource object
         * @param pathPart The path part for the child resource.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.apigateway.Resource addResource(final java.lang.String pathPart) {
            return this.jsiiCall("addResource", software.amazon.awscdk.services.apigateway.Resource.class, new Object[] { java.util.Objects.requireNonNull(pathPart, "pathPart is required") });
        }

        /**
         * Retrieves a child resource by path part.
         * 
         * EXPERIMENTAL
         * 
         * @return the child resource or undefined if not found
         * @param pathPart The path part of the child resource.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        @javax.annotation.Nullable
        public software.amazon.awscdk.services.apigateway.IResource getResource(final java.lang.String pathPart) {
            return this.jsiiCall("getResource", software.amazon.awscdk.services.apigateway.IResource.class, new Object[] { java.util.Objects.requireNonNull(pathPart, "pathPart is required") });
        }

        /**
         * Gets or create all resources leading up to the specified path.
         * 
         * - Path may only start with "/" if this method is called on the root resource.
         * - All resources are created using default options.
         * 
         * EXPERIMENTAL
         * 
         * @return a new or existing resource.
         * @param path The relative path.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.apigateway.Resource resourceForPath(final java.lang.String path) {
            return this.jsiiCall("resourceForPath", software.amazon.awscdk.services.apigateway.Resource.class, new Object[] { java.util.Objects.requireNonNull(path, "path is required") });
        }
    }
}
